@@ -4,12 +4,13 @@ from __future__ import annotations
 
 from datetime import datetime
 from enum import Enum
-from typing import List, Optional, Union
+from typing import List, Optional
 
 from pydantic import Field
-from pydantic.types import conlist
 
-from ..base import AindCoreModel, AindModel
+from aind_data_schema.base import AindCoreModel, AindModel
+from aind_data_schema.device import SizeUnit
+from aind_data_schema.imaging.tile import AcquisitionTile
 
 
 class AxisName(Enum):
@@ -45,7 +46,7 @@ class Axis(AindModel):
         ...,
         description="Tissue direction as the value of axis increases. If Other describe in notes.",
     )
-    unit: str = Field("micrometer", title="Axis physical units")
+    unit: SizeUnit = Field(SizeUnit.UM, title="Axis physical units")
 
     @staticmethod
     def from_direction_code(code) -> List[Axis]:
@@ -69,46 +70,6 @@ class Axis(AindModel):
         return axes
 
 
-class Channel(AindModel):
-    """Description of a channel"""
-
-    channel_name: str = Field(..., title="Channel")
-    laser_wavelength: int = Field(..., title="Wavelength", ge=300, le=1000)
-    laser_wavelength_unit: str = Field("nanometer", title="Laser wavelength unit")
-    laser_power: float = Field(..., title="Laser power", le=2000)
-    laser_power_unit: float = Field("milliwatt", title="Laser power unit")
-    filter_wheel_index: int = Field(..., title="Filter wheel index")
-
-
-class Scale3dTransform(AindModel):
-    """Values to be vector-multiplied with a 3D position, equivalent to the diagonals of a 3x3 transform matrix.
-    Represents voxel spacing if used as the first applied coordinate transform.
-    """
-
-    type: str = Field("scale", title="transformation type")
-    scale: conlist(float, min_items=3, max_items=3) = Field(..., title="3D scale parameters")
-
-
-class Translation3dTransform(AindModel):
-    """Values to be vector-added to a 3D position. Often needed to specify a Tile's origin."""
-
-    type: str = Field("translation", title="transformation type")
-    translation: conlist(float, min_items=3, max_items=3) = Field(..., title="3D translation parameters")
-
-
-class Tile(AindModel):
-    """Description of an image tile"""
-
-    coordinate_transformations: List[Union[Scale3dTransform, Translation3dTransform]] = Field(
-        ..., title="Tile coordinate transformations"
-    )
-    channel: Channel = Field(..., title="Channel")
-    file_name: Optional[str] = Field(None, title="File name")
-    notes: Optional[str] = Field(None, title="Notes")
-    imaging_angle: int = Field(0, title="Imaging angle")
-    imaging_angle_unit: str = Field("degree", title="Imaging angle unit")
-
-
 class Immersion(AindModel):
     """Description of immersion media"""
 
@@ -119,7 +80,7 @@ class Immersion(AindModel):
 class Acquisition(AindCoreModel):
     """Description of an imaging acquisition session"""
 
-    schema_version: str = Field("0.4.0", description="schema version", title="Version", const=True)
+    schema_version: str = Field("0.4.1", description="schema version", title="Version", const=True)
     experimenter_full_name: str = Field(
         ...,
         description="First and last name of the experimenter.",
@@ -129,7 +90,7 @@ class Acquisition(AindCoreModel):
     instrument_id: str = Field(..., title="Instrument ID")
     session_start_time: datetime = Field(..., title="Session start time")
     session_end_time: datetime = Field(..., title="Session end time")
-    tiles: List[Tile] = Field(..., title="Acquisition tiles")
+    tiles: List[AcquisitionTile] = Field(..., title="Acquisition tiles")
     axes: List[Axis] = Field(..., title="Acquisition axes")
     chamber_immersion: Immersion = Field(..., title="Acquisition chamber immersion data")
     sample_immersion: Optional[Immersion] = Field(None, title="Acquisition sample immersion data")
